@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::MakeMaker::Highlander;
 # ABSTRACT: There can be only one
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Moose 2;
 use List::AllUtils 'first';
@@ -19,7 +19,9 @@ sub setup_installer {
       or $self->log_fatal('No Makefile.PL found. Using [MakeMaker] is required');
 
     my $insert = <<'HERE';
+# Added by Dist::Zilla::Plugin::MakeMaker::Highlander
 if ( $] < 5.012
+  && ! $ENV{PERL_NO_HIGHLANDER}
   && ! ( $ENV{PERL_MM_OPT} && $ENV{PERL_MM_OPT} =~ /(?:INSTALL_BASE|PREFIX)/ )
   && ! grep { /INSTALL_BASE/ || /PREFIX/ } @ARGV
 ) {
@@ -55,7 +57,7 @@ Dist::Zilla::Plugin::MakeMaker::Highlander - There can be only one
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -76,6 +78,10 @@ C<INSTALL_BASE> or C<PREFIX>.
 This will result in warnings from old ExtUtils::MakeMaker, but appears to
 work nonetheless.
 
+If a build system already accounts for ExtUtils::MakeMaker's pathological
+bundling and C<UNINST = 1> causes problems, the C<PERL_NO_HIGHLANDER>
+environment variable may be set to a true value.
+
 =for Pod::Coverage setup_installer
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
